@@ -16,7 +16,7 @@
 G_BEGIN_DECLS
 
 #define BONOBO_TYPE_EVENT_SOURCE        (bonobo_event_source_get_type ())
-#define BONOBO_EVENT_SOURCE_TYPE        BONOBO_TYPE_EVENT_SOURCE // deprecated, you should use BONOBO_TYPE_EVENT_SOURCE
+#define BONOBO_EVENT_SOURCE_TYPE        BONOBO_TYPE_EVENT_SOURCE /* deprecated, you should use BONOBO_TYPE_EVENT_SOURCE */
 #define BONOBO_EVENT_SOURCE(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_TYPE_EVENT_SOURCE, BonoboEventSource))
 #define BONOBO_EVENT_SOURCE_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), BONOBO_TYPE_EVENT_SOURCE, BonoboEventSourceClass))
 #define BONOBO_IS_EVENT_SOURCE(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), BONOBO_TYPE_EVENT_SOURCE))
@@ -37,6 +37,8 @@ typedef struct {
 
 GType              bonobo_event_source_get_type         (void) G_GNUC_CONST;
 BonoboEventSource *bonobo_event_source_new              (void);
+gboolean           bonobo_event_source_has_listener     (BonoboEventSource *event_source,
+							 const char        *event_name);
 void               bonobo_event_source_notify_listeners (BonoboEventSource *event_source,
 							 const char        *event_name,
 							 const CORBA_any   *opt_value,
